@@ -54,6 +54,16 @@ class BaseProtocol(ABC):
     def class_name(self):
         return self.__class__.__name__
 
+    @property
+    def code(self):
+        return self.station
+
+    def __eq__(self, other):
+        if isinstance(other,str):
+            return self.station == other
+        else:
+            return self == other
+
     def create_socket(self, sock):
         sock = None
         if sock is None:
@@ -215,16 +225,19 @@ class BaseProtocol(ABC):
         )
         return idc
 
+    @property
+    def address(self):
+        return (self.host, self.port)
+
     def list_clients(self):
         for i in range(len(self.conss)):
             print(str(self.addrs[i]) + ":" + str(self.conns[i]))
 
-    async def close(self, idc):
+    async def async_close(self, idc):      
         self.logger.error("La conexión se cerró en cliente %s" % idc)
         self.status = False
         reader = self.clients[idc]['reader']
         writer = self.clients[idc]['writer']
-        writer.close()
         try:
             writer.close()
             await writer.wait_closed()
@@ -250,6 +263,13 @@ class BaseProtocol(ABC):
                 f"Close->Excepción no considerada al intentar leer e")
             raise e
 
+    async def close(self, idc=None):
+        if idc in self.idc:
+            await self.async_close(idc)
+        else:
+            for idc in self.clients:
+                await self.async_close(idc)
+
     async def stop(self):
         for idc in self.clients:
             await self.close(idc)
